summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorElliott Dahle <dedahle@us.ibm.com>2013-10-15 17:23:24 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-10-28 11:39:14 -0500
commit7b8d4a482ca2d110f3bf67b7a8e1bed758318420 (patch)
tree8084bc6829ee3f71527e9d2c937e5cb4e6e2eb96 /src/include
parent495ca1eff5f91ab577dc6b923bd766a6dfaa59ba (diff)
downloadtalos-hostboot-7b8d4a482ca2d110f3bf67b7a8e1bed758318420.tar.gz
talos-hostboot-7b8d4a482ca2d110f3bf67b7a8e1bed758318420.zip
HWPF Error XML Allow register collection based on present child chiplets
Change-Id: Ica9e4ef3636438f81f9f7fcdc80e8699ab0fc39d RTC: 80641 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/6686 Tested-by: Jenkins Server Reviewed-by: MIKE J. JONES <mjjones@us.ibm.com> Reviewed-by: Brian H. Horton <brianh@linux.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/hwpf/fapi/fapiCollectRegFfdc.H35
1 files changed, 25 insertions, 10 deletions
diff --git a/src/include/usr/hwpf/fapi/fapiCollectRegFfdc.H b/src/include/usr/hwpf/fapi/fapiCollectRegFfdc.H
index 30329cc75..7289a849c 100644
--- a/src/include/usr/hwpf/fapi/fapiCollectRegFfdc.H
+++ b/src/include/usr/hwpf/fapi/fapiCollectRegFfdc.H
@@ -40,6 +40,11 @@
* mjjones 09/19/2012 Created.
* dedahle 09/30/2013 Add i_child parameter for
* chiplet register FFDC
+ * dedahle 10/15/13 Added i_presChild and
+ * i_childOffsetMult
+ * parameters for register FFDC
+ * collection based on present
+ * child chiplets
*/
#ifndef FAPICOLLECTREGFFDC_H_
@@ -59,21 +64,31 @@ class ReturnCode;
* This should only be called by FAPI during FAPI_SET_HWP_ERROR or
* FAPI_ADD_INFO_TO_HWP_ERROR
*
* @param[in] i_target Reference to Target to collect FFDC from
* @param[in] i_ffdcId FFDC Identifier
* @param[out] o_rc Reference to ReturnCode that FFDC is added to
* @param[in] i_child Specifies type of i_target's chiplet to collect
* FFDC from. If this parameter is TARGET_TYPE_NONE
* (default value), then register FFDC is collected
* from i_target, else, register FFDC is collected
* from all functional child chiplets i_target of
* the specified type
*/
void fapiCollectRegFfdc(const fapi::Target & i_target,
const fapi::HwpFfdcId i_ffdcId,
fapi::ReturnCode & o_rc,
const fapi::TargetType i_child =
- fapi::TARGET_TYPE_NONE);
+ fapi::TARGET_TYPE_NONE,
+ const fapi::TargetType i_presChild =
+ fapi::TARGET_TYPE_NONE,
+ const uint32_t i_childOffsetMult = 0);
}
#endif
OpenPOWER on IntegriCloud
@@ -59,21 +64,31 @@ class ReturnCode;
* FAPI_ADD_INFO_TO_HWP_ERROR
*
- * @param[in] i_target Reference to Target to collect FFDC from
- * @param[in] i_ffdcId FFDC Identifier
- * @param[out] o_rc Reference to ReturnCode that FFDC is added to
- * @param[in] i_child Specifies type of i_target's chiplet to collect
- * FFDC from. If this parameter is TARGET_TYPE_NONE
- * (default value), then register FFDC is collected
- * from i_target, else, register FFDC is collected
- * from all functional child chiplets i_target of
- * the specified type
+ * @param[in] i_target Reference to Target to collect FFDC from
+ * @param[in] i_ffdcId FFDC Identifier
+ * @param[out] o_rc Reference to ReturnCode that FFDC is added to
+ * @param[in] i_child Specifies type of i_target's chiplet to collect
+ * FFDC from. If this parameter is TARGET_TYPE_NONE
+ * (default value), then register FFDC is collected
+ * from i_target, else, register FFDC is collected
+ * from all functional child chiplets i_target of
+ * the specified type
+ * @param[in] i_presChild When specified, register FFDC will be collected
+ * from i_target's registers based on present chiplets
+ * of this type.
+ * @param[in] i_childOffsetMult Specifies the chiplet position offset multiplier.
+ * This is used in calculating the scom register
+ * addresses when collecting register FFDC based on
+ * present child chiplets.
*/
void fapiCollectRegFfdc(const fapi::Target & i_target,